@@ -1,18 +1,18 @@
 ;(function(){
   var map = {
-  "commitId": "c39ac0850442aaf624ab4d8438c883d9aa313c8f",
-  "branchName": "release-client-6.x",
-  "buildTime": "2024-12-13 01:26:17 GMT",
-  "buildVersion": "1.0.1460",
+  "commitId": "edcfa2f953d28f98047263d0aa23d62a5374b69d",
+  "branchName": "release-client-6.3.x",
+  "buildTime": "2025-02-14 03:55:34 GMT",
+  "buildVersion": "1.0.2649",
   "css": [
-    "@zoom/client-scheduler/static/css/chunk-vendors.b08a77b8.css",
-    "@zoom/client-scheduler/static/css/index.60f74ba0.css"
+    "@zoom/client-calendar-desktop/static/css/chunk-vendors.b9dfd765.css",
+    "@zoom/client-calendar-desktop/static/css/app.fc853fe3.css"
   ],
   "js": [
-    "@zoom/client-scheduler/chunk-vendors.83594c8447326f77f45b.js",
-    "@zoom/client-scheduler/index.83594c8447326f77f45b.js"
+    "@zoom/client-calendar-desktop/static/js/chunk-vendors.1051148d.js",
+    "@zoom/client-calendar-desktop/static/js/app.07c5ef74.js"
   ],
-  "key": "clientSchedulerResource"
+  "key": "@zoom/client-calendar-desktop"
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
   map.css && map.css.forEach(function (cssItem) {
